@@ -5,6 +5,7 @@ from cow.server import Server
 from cow.plugins.motor_plugin import MotorPlugin
 from cow.plugins.redis_plugin import RedisPlugin
 from cow.plugins.es_plugin import ESPlugin
+from cow.plugins.geopy_google_plugin import GeoPyGooglePlugin
 
 from tests.sandbox.handlers.test import TestHandler
 
@@ -19,7 +20,8 @@ class SandboxServer(Server):
         return [
             MotorPlugin,
             RedisPlugin,
-            ESPlugin
+            ESPlugin,
+            GeoPyGooglePlugin
         ]
 
 if __name__ == '__main__':
